穿越时空的少女 (豆瓣)
Description: 穿越时空的少女电影简介和剧情介绍,穿越时空的少女影评、图片、预告片、影讯、论坛、在线购票
Keywords: 穿越时空的少女,時をかける少女,穿越时空的少女影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.247豆瓣电影Top250

# 穿越时空的少女 時をかける少女 (2006)

导演: 细田守
编剧: 奥寺佐渡子 / 筒井康隆
主演: 仲里依纱 / 石田卓也 / 板仓光隆 / 垣内彩未 / 谷村美月 / 关户优希 / 桂歌若 / 安藤绿 / 立木文彦 / 山本圭子 / 反田孝幸 / 谷川清美 / 汤屋敦子 / 松田洋治 / 中村正 / 原沙知绘
类型: 剧情 / 爱情 / 科幻 / 动画
官方网站: www.kadokawa.co.jp/tokikake/
制片国家/地区: 日本
语言: 日语
上映日期: 2006-07-15(日本)
片长: 98分钟
又名: 跳跃吧！时空少女(台) / Toki o kakeru shôjo / The Girl Who Leapt Through Time
IMDb: tt0808506
豆瓣评分
引用
8.6
365539人评价
5星
45.8%
4星
40.7%
3星
12.2%
2星
1.0%
1星
0.2%
好于 96% 动画片
好于 97% 爱情片
想看 看过
评价:
推荐

## 穿越时空的少女的剧情简介 · · · · · ·

17岁少女绀野真琴是一个活泼跳脱的少女。在一次普通值日工作中，真琴不小心摔倒了，自此她发现自己拥有了穿越时空的能力。她兴奋不已，掌握了穿越时空的方法后，她经常用这个方法去解决生活中许多令她困扰十分的事。
喜欢棒球的真琴与同班的两名男生千昭与功介有着共同爱好。一天，与她本是好朋友的千昭突然向她表达爱意，手足无措了她再次穿越时空希望可以躲避这件事的发生。但没想到，千昭会跟同学友梨在一起了，而友梨也是一直喜欢千昭的。此时，暗恋功介的果穗误以为真琴是功介的女友。
为了帮忙解决朋友的问题，真琴不断以同样的方法回到过去。她突然发现自己手臂上的数字原来是穿越时空的次数，次数变得越来越少，与此同时她也发现了千昭的秘密…… ©豆瓣

## 穿越时空的少女的演职员 · · · · · · ( 全部 26 )

- 细田守 导演
- 仲里依纱 配 绀野真琴
- 石田卓也 配 间宫千昭
- 板仓光隆 配 津田功介
- 垣内彩未 配 早川友梨
- 谷村美月 配 藤谷果穂

## 穿越时空的少女的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片546 · 添加 )

## 穿越时空的少女的获奖情况 · · · · · · ( 全部 )

- 第30届日本电影学院奖
- 最佳动画片

- 第31届报知映画赏
- 特别奖
- 细田守

## 喜欢这部电影的人也喜欢 · · · · · ·

  夏日大作战

  幽灵公主

  天空之城

  风之谷

  哈尔的移动城堡

  魔女宅急便

  猫的报恩

  千年女优

  红猪

  红辣椒

我要写短评

## 穿越时空的少女的短评 · · · · · · ( 全部 85058 条 )

热门 / 最新 / 好友

### 1622 有用 果酱☮ 看过 2009-05-22 00:32:58

打多少星都不够

### 948 有用 匡轶歌 看过 2015-06-27 23:53:36

画风蛮喜欢。不必去深究时间穿越这个设置背后凌乱的逻辑，片子其实只说了一件事：Time waits for no one ，做自己喜欢的事、爱自己所爱的人，都要现在就去，跑着去。倘若对方姗姗来迟，你就要跑着去迎接它。时不我待，只争朝夕。

### 834 有用 风满蜃气楼 看过 2009-11-30 18:11:49

最后千昭的那句“我在未来等你"足以秒杀一切。 放课后的棒球、蝉鸣、反复跳跃只为吃到一个布丁，缺乏的勇气和自行车一遍遍经过的河堤，所有的一切都融化在那个夏天和你分离。

### 1474 有用 littletwo 看过 2008-05-15 23:40:33

我在未来等你...

### 477 有用 大头绿豆 看过 2007-07-22 22:29:28

爱杀真琴的性格和他们仨的感情。时间静止的画面。动画比人演得好！吉田潔的音乐大赞。

> 更多短评 85058条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 穿越时空的少女的影评 · · · · · · ( 全部 1266 条 )

热门 / 最新 / 好友
伊谢尔伦的风 2007-08-14 21:23:55

## 白驹飞驰，青春过隙。

赶在人生最后一个暑假尚未谢幕。 —————————— 青春有张不老的脸 蝉鸣，树影，白云，夏天，钢琴声响，棒球手套，骑车上学时的凉风，傍晚放学后的夕阳，图书馆书架间微微的凉意，篮球场里永无休止的喧嚣。时光日复一日奔涌不止，但和平时代的青春，却似乎永远都是这副... (展开)
3065 138 277回应 收起
水木丁 2008-02-23 12:03:57

## 人的心，山高水长

邦妮在博客上推荐《穿越时空的少女》，到网上下载来看，很可爱的故事，年轻的女孩得到穿越时空的能力，觉得好玩，就没完没了的瞎折腾，一点破事儿不满意都要回到过去把它纠正过来，但是说是纠正，又不知道往哪里纠，什么是正，总之一来二去的非要把事情弄对了不可，为的只是和... (展开)
1383 63 136回应 收起
柏邦妮 2009-04-23 11:53:24

## 穿越时空的少女和穿越少女的时空

穿越时空的少女和穿越少女的时空 柏邦妮 每个人的生命中都有一些截点。回忆到了那里，就停住了。当然，我们总是在往前走，不得不走，带着所有光荣和残破和平淡和幸福往前走。但是你知道，你不是完整的。一部分的你被时光拦截下来，她和你挥手告别，永远的留在那里。剩下的部... (展开)
744 37 65回应 收起
丁萌 2010-12-24 13:16:54

## 结构主义的穿越故事

几年前，原作者筒井康隆的小说《文学部唯野教授》译成中文出版。这部形式奇特的小说几乎有一半篇幅是由文学理论“教案”构成，这半本书，夸张点说，丝毫没有“虚构”的成分。考虑到这一点，认真对待这部动画片，就有了一些正当的理由了。 一个关于“穿越”主题的故事，总是不... (展开)
346 19 21回应 收起
卡卡 2007-05-07 11:27:08

## 时间只为你停留

2007-05-01 18:55:50 　　来自: 卡卡 当你在使用一种能力的时候，也许会对别人造成伤害。 　　 　　魔女阿姨说着这样的话的时候，绀野真琴也许永远不会意识到在某一个顺流逆流的时空里面，失灵的自行车刹车会带走津田功介和他刚认识的女朋友的生命，而那也许还不是所有遗憾... (展开)
366 24 42回应 收起
乐乐Artle 2007-06-14 00:01:03

## 回不了的过去，看不到的未来

在我为一件事情如何做决定而犹豫不决的时候，熊猫老哥推荐了《穿越时空的少女》给我。他说，你看完这个片子，再告诉我你的决定是什么。那阵子因为忙，也一直没有看那个片子，也没有做任何决定，只是在别人帮助下想到了很好的理由去推迟时间。直到今天，我才明白熊猫的心意。... (展开)
245 25 40回应 收起
soso 2009-03-24 22:03:38

## 哥德堡变奏曲

看这部动画片已经快一年前的事了。巴赫的哥德堡变奏曲在这部电影之中可以说运用的十分精巧贴切，看到有不少观众都在电影中发现了这段美妙的巴洛克音乐。但是其中却有一些细节很少见人提起，所以忍不住想拿出来分享讨论下。 大约在影片8分多钟时，哥德堡变奏曲的原主题... (展开)
180 3 17回应 收起
風真≈ 2007-04-28 10:24:02

## 从take care of yourself到time waits for no one

GAINAX不在，贞本坐镇，角川当仁不让接下“新世纪骗钱大法”，重炒筒井康隆1967年的经典同名小说《穿越时空的少女》。 这个标志就产生于”Time waits for no one” 取代了当年EVA剧场版《真心为你》的经典话语 “Take care of yourself.” 当年EVA风靡、炒作的最高潮时，世界末... (展开)
143 32 34回应 收起
明海 2013-12-18 01:52:54

## 可能是我看过最糟糕的时间旅行题材作品

这篇影评可能有剧透

之前看了细田守的雨雪，一下喜欢上了这个导演，于是把本作拿来看了。其实很早就知道这部作品，只是一直没看。 我并不喜欢对设定上的漏洞指手画脚，毕竟号称严谨的SG都有无数解释不清的地方。时空旅行嘛，看个剧情就好。 问题是，当涉及作品的核心部分有问题时，你显然不能视... (展开)
153 67 82回应 收起
苏梦枕 2008-05-29 19:01:29

## Time waits for no one

直到它的三分之二，我还在想其实不过一个很普通的片子罢了。当然有很多可取处，正如每一部都还不错的片子，但也就是不错，而已。 这个女孩，额头光洁，有着小鹿一样温顺的眼睛，哭泣的时候，大颗大颗的泪珠自眼角蹦落，会让人，尤其一些神经细腻的人，不能不为其喜而喜，为其... (展开)
107 3 19回应 收起

> 更多影评 1266篇

添加新讨论

## 讨论区 · · · · · ·

开头真琴听到妹妹的声音是怎么回事..弓介不也喜欢... | 来自. | 1 回应 | 2022-11-16 21:45:40
未来的人请留言 | 来自小菜一碟子 | 7 回应 | 2022-11-10 09:18:54
为什么真琴最后又获得一次穿越时空的机会？ | 来自纠结夫斯基 | 10 回应 | 2022-10-29 03:20:36
女主真的是很笨! | 来自多情的大黄蜂 | 1 回应 | 2022-10-24 16:20:30
有没有和我一样现实中不喜欢女主这种人的 | 来自🌀玄玉公子🌀 | 7 回应 | 2022-10-24 16:18:09

> 去这部影片的讨论区（全部199条）

## 关于《穿越时空的少女》的问题 · · · · · · ( 全部25个 )

- 一开始真琴在实验室看到的那个人到底是谁啊？ 5人回答
- 千昭和真琴不可能再见面了吧？ 12人回答

> 全部25个问题

## 在哪儿看这部电影 · · · · · ·

- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 日式青春 (沉歌)
- 【大爱の日剧♂电影♀动画全收录】 (狷介有乌青)
- 治愈系动画推荐 ([己注销])
- 【爱看动画】 (影志)

## 谁在看这部电影 · · · · · ·

- Serendipity
  1分钟前 想看
- ChiaraC
  9分钟前 看过
- momo
  10分钟前 想看

532016人看过 / 204259人想看

订阅穿越时空的少女的评论:
feed: rss 2.0